==> tuia-news-center-api-0.0.16-zwb-20180410.022704-2-sources.jar: cn/com/duiba/tuia/news/center/dto/NewsActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.util.Date;

import cn.com.duiba.tuia.news.center.enums.ActivityType;

public class NewsActivityDto extends BaseQueryDto {

    private Long    id;

    /** 活动名称 */
    private String  activityName;

    /** 活动链接 */
    private String  activityUrl;

    /** 活动图片 */
    private String  activityImage;

    /** 排序值 */
    private Integer sortNum;

    /** 曝光数量 */
    private Long    exposureCount;

    /** 点击数量 */
    private Long    clickCount;

    /** 是否删除 */
    private Boolean delete;

    private Date    gmtCreate;

    private Date    gmtModified;

    /** 活动来源 */
    private String  activitySource;

    /** 是否启用 */
    private Boolean enable;

    /** 活动类型 {@link ActivityType} */
    private Integer activityType;

    /** 活动大图 */
    private String activityBigImage;

    /** 类目 */
    private String  tip;

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public Boolean getDelete() {
        return delete;
    }

    public void setDelete(Boolean delete) {
        this.delete = delete;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl == null ? null : activityUrl.trim();
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage == null ? null : activityImage.trim();
    }

    public Integer getSortNum() {
        return sortNum;
    }

    public void setSortNum(Integer sortNum) {
        this.sortNum = sortNum;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-0.0.28-zwb15-20180515.133838-2-sources.jar: cn/com/duiba/tuia/news/center/dto/NewsActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.util.Date;

import cn.com.duiba.tuia.news.center.enums.ActivityType;

public class NewsActivityDto extends BaseQueryDto {

    private Long    id;

    /** 活动名称 */
    private String  activityName;

    /** 活动链接 */
    private String  activityUrl;

    /** 活动图片 */
    private String  activityImage;

    /** 排序值 */
    private Integer sortNum;

    /** 曝光数量 */
    private Long    exposureCount;

    /** 点击数量 */
    private Long    clickCount;

    /** 是否删除 */
    private Boolean delete;

    private Date    gmtCreate;

    private Date    gmtModified;

    /** 活动来源 */
    private String  activitySource;

    /** 是否启用 */
    private Boolean enable;

    /** 活动类型 {@link ActivityType} */
    private Integer activityType;

    /** 活动大图 */
    private String activityBigImage;

    /** 类目 */
    private String  tip;

    /*广告Id*/
    private String activityId;

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public Boolean getDelete() {
        return delete;
    }

    public void setDelete(Boolean delete) {
        this.delete = delete;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl == null ? null : activityUrl.trim();
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage == null ? null : activityImage.trim();
    }

    public Integer getSortNum() {
        return sortNum;
    }

    public void setSortNum(Integer sortNum) {
        this.sortNum = sortNum;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
